@@ -3,11 +3,13 @@ package MooX::ConfigFromFile;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
+
+my %loaded_configs;
 
 sub import
 {
-    my ( undef, @import ) = @_;
+    my ( undef, %import_options ) = @_;
     my $target = caller;
     my @target_isa;
     { no strict 'refs'; @target_isa = @{"${target}::ISA"} };
@@ -24,6 +26,35 @@ sub import
     };
     $apply_modifiers->();
 
+    my $around;
+    defined $import_options{config_singleton} and $import_options{config_singleton} and do
+    {
+        $around or $around = $target->can('around');
+        $around->(
+            _build_loaded_config => sub {
+                my $orig  = shift;
+                my $self  = shift;
+                my $class = ref $self ? ref $self : $self;
+                defined $loaded_configs{$class} or $loaded_configs{$class} = $self->$orig(@_);
+                return $loaded_configs{$class};
+            }
+        );
+    };
+
+    my %default_modifiers = (
+        config_prefix     => '_build_config_prefix',
+        config_extensions => '_build_config_extensions',
+        config_dirs       => '_build_config_dirs',
+        config_files      => '_build_config_files',
+    );
+
+    foreach my $opt_key ( keys %default_modifiers )
+    {
+        exists $import_options{$opt_key} or next;
+        $around or $around = $target->can('around');
+        $around->( $default_modifiers{$opt_key} => sub { $import_options{$opt_key} } );
+    }
+
     return;
 }
 
@@ -68,7 +99,8 @@ MooX::ConfigFromFile - Moo eXtension for initializing objects from config file
 
    use Moo;
 
-   use MooX::ConfigFromFile; # imports the MooX::ConfigFromFile::Role
+   # consumes the MooX::ConfigFromFile::Role but load config only once
+   use MooX::ConfigFromFile config_singleton => 1;
 
    with "Role::Action";
 
@@ -93,6 +125,41 @@ on object construction from an appropriate config file. The building is
 done in L<MooX::ConfigFromFile::Role> - using MooX::ConfigFromFile ensures
 the role is applied.
 
+For easier usage, with 0.004, several options can be passed via I<use> resulting
+in default initializers for appropriate role attributes:
+
+=over 4
+
+=item C<config_prefix>
+
+Default for L<MooX::ConfigFromFile::Role/config_prefix>.
+
+=item C<config_extensions>
+
+Default for L<MooX::ConfigFromFile::Role/config_extensions>.
+
+=item C<config_dirs>
+
+Default for L<MooX::ConfigFromFile::Role/config_dirs>.
+Same warning regarding modifying this attribute applies here:
+Possible, but use with caution!
+
+=item C<config_files>
+
+Default for L<MooX::ConfigFromFile::Role/config_files>.
+
+Reasonable when you want exactly one config file in development mode.
+For production code it is highly recommended to override the builder.
+
+=item C<config_singleton>
+
+Flag adding a wrapper L<< around|Class::Method::Modifiers/around method(s) => sub { ... }; >>
+the I<builder> of L<MooX::ConfigFromFile::Role/loaded_config> to ensure a
+config is loaded only once per class. The I<per class> restriction results
+from applicable modifiers per class (and singletons are per class).
+
+=back
+
 =head1 AUTHOR
 
 Jens Rehsack, C<< <rehsack at cpan.org> >>
@@ -133,10 +200,8 @@ L<http://search.cpan.org/dist/MooX-ConfigFromFile/>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2013-2014 Jens Rehsack.
